==> download-2023.1.27_11.4.15-root-(instance-1.us-central1-a.c.ayaingenieria.internal).tar.gz: app/Http/Controllers/prefactura/mantenedorController.php <==
<?php

namespace App\Http\Controllers\prefactura;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use DB;
use App;
use App\kilometros_ciudad_bases;
use Carbon\Carbon;
use Crypt;

class mantenedorController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $kilometros = kilometros_ciudad_bases::where('estado','=','1')->paginate(100);

        $ciudad_base = DB::table ('ciudad_bases')
        ->select('id','ciudad_base')
        ->orderby('ciudad_base','ASC')
        ->get();

        $ciudades = DB::table('kilometros_ciudad_bases')
        ->select('ciudad')
        ->orderby('ciudad','ASC')
        ->where('id_ciudad_bases','=','1')
        
        ->get();



        // $ciudadesKilometros = DB::table ('ciudad_bases')
        // ->join('kilometros_ciudad_bases',"kilometros_ciudad_bases.id_ciudad_bases","=","ciudad_bases.id")
        // ->select('ciudad_bases.id','ciudad_bases.ciudad_base','kilometros_ciudad_bases.ciudad')
        // ->orderby('ciudad_bases.ciudad_base','ASC')
        // ->get();

         //   return $ciudadesKilometros;

        return view('check.ver_mantenedor_kilometros', compact('kilometros','ciudad_base','ciudades'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
 
        $kilometros_ciudad_bases = new App\kilometros_ciudad_bases;
        $kilometros_ciudad_bases->id_ciudad_bases =  $request->cBase;
        $kilometros_ciudad_bases->ciudad =  $request->cOrigen;
        $kilometros_ciudad_bases->kilometros =  $request->crearKilometros;
        $kilometros_ciudad_bases->timestamps = false;
        $kilometros_ciudad_bases->save();

        return back()->with('mensaje', 'Kilometro Creados');


    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy( request $request )
    {


        $kilometros = App\kilometros_ciudad_bases::findOrFail($request->idkilometros);
        $kilometros->estado = 0;
        $kilometros->timestamps = false;
        $kilometros->save();

        return back()->with('mensaje', 'Kilometro Eliminado');
    }

    public function filtros_mantenedor_kilometros(Request $request)
    {

        $ciudad_base = $request->ciudad_base;
        $ciudad_destino = $request->ciudad_destino;

        $where  = "";

        if($ciudad_base == "" &&  $ciudad_destino == ""){

            $kilometros = kilometros_ciudad_bases::where('estado','=','1')->paginate(100);

        }else{

            if($ciudad_base != "" && $ciudad_destino == ""){
     
                $kilometros = kilometros_ciudad_bases::where("id_ciudad_bases","=",$ciudad_base)->paginate(100);
        
            }
            if($ciudad_base != "" && $ciudad_destino != ""){

                $kilometros = kilometros_ciudad_bases::where("id_ciudad_bases","=",$ciudad_base)->where("ciudad","=",$ciudad_destino)->paginate(100);
                
            }
            if($ciudad_base == "" && $ciudad_destino != ""){

                $kilometros = kilometros_ciudad_bases::where("ciudad","=",$ciudad_destino)->paginate(100);

            }
            //$kilometros = DB::select('select id,id_ciudad_bases,ciudad,kilometros
            //from kilometros_ciudad_bases where '.$where . "" );
        }

        $ciudad_base = DB::table ('ciudad_bases')
            ->select('id','ciudad_base')
            ->orderby('ciudad_base','ASC')
            ->get();

        $ciudades = DB::table('kilometros_ciudad_bases')
            ->select('ciudad')
            ->orderby('ciudad','ASC')
            ->where('id_ciudad_bases','=','1')
            
            ->get();

            // $ciudadesKilometros = DB::table ('ciudad_bases')
            // ->join('kilometros_ciudad_bases')
            // ->select('ciudad_bases.id','ciudad_base.ciudad_base','kilometros_ciudad_bases.ciudad')
            // ->orderby('ciudad_bases.ciudad_base','ASC')
            // ->get();

            //     return $ciudadesKilometros;
    
        return view('check.ver_mantenedor_kilometros', compact('kilometros','ciudad_base','ciudades'));
    }

    public function ver_datos_kilometros(request $request){

        $kilometrosid = $request->id;
        $datoscostos = kilometros_ciudad_bases::where('id','=',$kilometrosid)->first();
        return $datoscostos;
    }

    public function editar (request $request){

        $id = $request->id;

        $kilometros = App\kilometros_ciudad_bases::findOrFail($id);
        $kilometros->kilometros = $request->kilometros;
        $kilometros->timestamps = false;
        $kilometros->save();

        return back()->with('mensaje', 'Kilometro modificado');

    }
}

==> download-2023.8.1_13.1.34-root-(instance-1.us-central1-a.c.ayaingenieria.internal).tar.gz: app/Http/Controllers/prefactura/mantenedorController.php <==
<?php

namespace App\Http\Controllers\prefactura;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use DB;
use App;
use App\kilometros_ciudad_bases;
use Carbon\Carbon;
use Crypt;

class mantenedorController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
     

        $kilometros = kilometros_ciudad_bases::where('estado','=','1')->paginate(100);

        $ciudad_base = DB::table ('ciudad_bases')
        ->select('id','ciudad_base')
        ->orderby('ciudad_base','ASC')
        ->get();

        $ciudades = DB::table('kilometros_ciudad_bases')
        ->select('ciudad')
        ->orderby('ciudad','ASC')
        ->where('id_ciudad_bases','=','nosemuestra')
        
        ->get();



        // $ciudadesKilometros = DB::table ('ciudad_bases')
        // ->join('kilometros_ciudad_bases',"kilometros_ciudad_bases.id_ciudad_bases","=","ciudad_bases.id")
        // ->select('ciudad_bases.id','ciudad_bases.ciudad_base','kilometros_ciudad_bases.ciudad')
        // ->orderby('ciudad_bases.ciudad_base','ASC')
        // ->get();

         //   return $ciudadesKilometros;

        return view('check.ver_mantenedor_kilometros', compact('kilometros','ciudad_base','ciudades'));
    }
    public function ver_datos_kilometros_filtros(request $req)
    {
     
        $opciones = DB::table('kilometros_ciudad_bases')
        ->select('ciudad','kilometros_ciudad_bases.id as id_kiliometros')
        ->orderby('ciudad','ASC')
        ->where('id_ciudad_bases','=',$req->id)
        
        ->get();

        $select="";
              foreach ($opciones as $valor) {


                 $select .= '<option name="ciudad_destino" value="' . $valor->id_kiliometros. '">' .  $valor->ciudad. '</option>';
             }

        return $select;

       
    }


    

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
 
        $kilometros_ciudad_bases = new App\kilometros_ciudad_bases;
        $kilometros_ciudad_bases->id_ciudad_bases =  $request->cBase;
        $kilometros_ciudad_bases->ciudad =  $request->cOrigen;
        $kilometros_ciudad_bases->kilometros =  $request->crearKilometros;
        $kilometros_ciudad_bases->timestamps = false;
        $kilometros_ciudad_bases->save();

        return back()->with('mensaje', 'Kilometro Creados');


    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy( request $request )
    {


        $kilometros = App\kilometros_ciudad_bases::findOrFail($request->idkilometros);
        $kilometros->estado = 0;
        $kilometros->timestamps = false;
        $kilometros->save();

        return back()->with('mensaje', 'Kilometro Eliminado');
    }

    public function filtros_mantenedor_kilometros(Request $request)
    {


        $ciudad_base = $request->ciudad_base;
        $ciudad_destino = $request->ciudad_destino;

        $where  = "";

        if($ciudad_base == "" &&  $ciudad_destino == ""){

            $kilometros = kilometros_ciudad_bases::where('estado','=','1')->paginate(100);

        }else{

            if($ciudad_base != "" && $ciudad_destino == ""){

                $kilometros = kilometros_ciudad_bases::where("id_ciudad_bases","=",$ciudad_base)->paginate(100);
        
            }
            if($ciudad_base != "" && $ciudad_destino != ""){

                

                $kilometros = kilometros_ciudad_bases::where("id_ciudad_bases","=",$ciudad_base)->where("id","=",$ciudad_destino)->paginate(100);
            }
            if($ciudad_base == "" && $ciudad_destino != ""){

                $kilometros = kilometros_ciudad_bases::where("id","=",$ciudad_destino)->paginate(100);

            }
            //$kilometros = DB::select('select id,id_ciudad_bases,ciudad,kilometros
            //from kilometros_ciudad_bases where '.$where . "" );
        }

        $ciudad_base = DB::table ('ciudad_bases')
            ->select('id','ciudad_base')
            ->orderby('ciudad_base','ASC')
            ->get();

        $ciudades = DB::table('kilometros_ciudad_bases')
            ->select('ciudad')
            ->orderby('ciudad','ASC')
            ->where('id_ciudad_bases','=','1')
            
            ->get();

            // $ciudadesKilometros = DB::table ('ciudad_bases')
            // ->join('kilometros_ciudad_bases')
            // ->select('ciudad_bases.id','ciudad_base.ciudad_base','kilometros_ciudad_bases.ciudad')
            // ->orderby('ciudad_bases.ciudad_base','ASC')
            // ->get();

            //     return $ciudadesKilometros;
    
        return view('check.ver_mantenedor_kilometros', compact('kilometros','ciudad_base','ciudades'));
    }

    public function ver_datos_kilometros(request $request){

        $kilometrosid = $request->id;
        $datoscostos = kilometros_ciudad_bases::where('id','=',$kilometrosid)->first();
        return $datoscostos;
    }

    public function editar (request $request){

        $id = $request->id;

        $kilometros = App\kilometros_ciudad_bases::findOrFail($id);
        $kilometros->kilometros = $request->kilometros;
        $kilometros->timestamps = false;
        $kilometros->save();

        return back()->with('mensaje', 'Kilometro modificado');

    }
}
